# Generated by Django 2.0.2 on 2018-04-14 00:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('referrals', '0005_auto_20180413_1850'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='flatreferral',
            table='flat_referral',
        ),
    ]
