# Generated by Django 2.0.2 on 2018-04-13 21:31

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('referrals', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='referral',
            options={'ordering': ['id']},
        ),
        migrations.AlterField(
            model_name='referral',
            name='referred',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='referred', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='referral',
            name='referrer',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='referrer', to=settings.AUTH_USER_MODEL),
        ),
    ]
