# Generated by Django 2.0.2 on 2018-04-13 23:50

from django.conf import settings
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('referrals', '0004_auto_20180413_1813'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='Referral',
            new_name='FlatReferral',
        ),
    ]
